lilypondfiletools.HeaderBlock
=============================

.. inheritance-diagram:: abjad.tools.lilypondfiletools.HeaderBlock.HeaderBlock.HeaderBlock
   :private-bases:

.. autoclass:: abjad.tools.lilypondfiletools.HeaderBlock.HeaderBlock.HeaderBlock

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.HeaderBlock.HeaderBlock.HeaderBlock.format

    Inherited from :py:class:`lilypondfiletools.AttributedBlock <abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.HeaderBlock.HeaderBlock.HeaderBlock.is_formatted_when_empty

    Inherited from :py:class:`lilypondfiletools.AttributedBlock <abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock>`

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.HeaderBlock.HeaderBlock.HeaderBlock.__delattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.HeaderBlock.HeaderBlock.HeaderBlock.__hash__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.HeaderBlock.HeaderBlock.HeaderBlock.__repr__

    Inherited from :py:class:`lilypondfiletools.AttributedBlock <abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock.AttributedBlock>`

.. automethod:: abjad.tools.lilypondfiletools.HeaderBlock.HeaderBlock.HeaderBlock.__setattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lilypondfiletools.HeaderBlock.HeaderBlock.HeaderBlock.__str__

    Inherited from `__builtin__.object`
